@@ -1,4 +1,4 @@
-/*  $Id: newsfeeds.c 6156 2003-01-19 20:58:05Z rra $
+/*  $Id: newsfeeds.c 7730 2008-04-06 08:27:16Z iulius $
 **
 **  Routines for the in-core data structures for the newsfeeds file.
 */
@@ -448,6 +448,7 @@ SITEparseone(char *Entry, SITE *sp, char *subbed, char *poison)
     int			isp;
     SITE		*nsp;
     struct buffer	b;
+    HASHFEEDLIST	*hf;
 
     b = sp->Buffer;
     *sp = SITEnull;
@@ -467,6 +468,7 @@ SITEparseone(char *Entry, SITE *sp, char *subbed, char *poison)
     sp->NeedOverviewCreation = false;
     sp->FeedwithoutOriginator = false;
     sp->DropFiltered = false;
+    sp->HashFeedList = NULL;
 
     /* Nip off the first field, the site name. */
     if ((f2 = strchr(Entry, NF_FIELD_SEP)) == NULL)
@@ -603,6 +605,37 @@ SITEparseone(char *Entry, SITE *sp, char *subbed, char *poison)
             if (*++p && CTYPE(isdigit, *p))
                 sp->Nice = atoi(p);
             break;
+	case 'Q':
+	    hf = xmalloc(sizeof(HASHFEEDLIST));
+	    p++;
+            /* Check whether it is a quickhash or a MD5 hashfeed. */
+	    if (*p == '@') {
+		p++;
+		hf->type = HASHFEED_QH;
+	    } else
+		hf->type = HASHFEED_MD5;
+            /* Check the presence of a starting byte-offset for hashfeed. */
+	    if ((u = strchr(p, '_')) != NULL) {
+		if (sscanf(u + 1, "%u", &hf->offset) != 1 || hf->offset > 12) {
+		    free(hf);
+		    return "invalid hash offset for Q param in field 3";
+		}
+	    } else
+		hf->offset = 0;
+            if (sscanf(p, "%u/%u", &hf->begin, &hf->mod) == 2) {
+                hf->end = hf->begin;
+            } else if (sscanf(p, "%u-%u/%u", &hf->begin, &hf->end,
+                              &hf->mod) != 3) {
+                free(hf);
+                return "hash not in x/z or x-y/z format for Q param in field 3";
+            }
+            if (hf->begin > hf->end || hf->end > hf->mod) {
+                free(hf);
+                return "incorrect hash values for Q param in field 3";
+            }
+	    hf->next = sp->HashFeedList;
+	    sp->HashFeedList = hf;
+	    break;
 	case 'S':
 	    if (*++p && CTYPE(isdigit, *p))
 		sp->StartSpooling = atol(p);
