@@ -1,4 +1,4 @@
-/*  $Id: site.c 6716 2004-05-16 20:26:56Z rra $
+/*  $Id: site.c 7748 2008-04-06 13:49:56Z iulius $
 **
 **  Routines to implement site-feeding.  Mainly working with channels to
 **  do buffering and determine what to send.
@@ -390,11 +390,18 @@ SITEwritefromflags(SITE *sp, ARTDATA *Data)
 	case FEED_PATH:
 	    if (Dirty)
 		buffer_append(bp, ITEMSEP, strlen(ITEMSEP));
-	    if (!Data->Hassamepath)
-		buffer_append(bp, Path.data, Path.used);
-	    if (Data->AddAlias)
-		buffer_append(bp, Pathalias.data, Pathalias.used);
-	    buffer_append(bp, HDR(HDR__PATH), HDR_LEN(HDR__PATH));
+            if (!Data->Hassamepath || Data->AddAlias || Pathcluster.used) {
+                if (Pathcluster.used)
+                    buffer_append(bp, Pathcluster.data, Pathcluster.used);
+                buffer_append(bp, Path.data, Path.used);
+                if (Data->AddAlias)
+                    buffer_append(bp, Pathalias.data, Pathalias.used);
+            }
+            if (Data->Hassamecluster)
+                buffer_append(bp, HDR(HDR__PATH) + Pathcluster.used,
+                              HDR_LEN(HDR__PATH) - Pathcluster.used);
+            else
+                buffer_append(bp, HDR(HDR__PATH), HDR_LEN(HDR__PATH));
 	    break;
 	case FEED_REPLIC:
 	    if (Dirty)
@@ -997,6 +1004,7 @@ void
 SITEfree(SITE *sp)
 {
     SITE                *s;
+    HASHFEEDLIST	*hf, *hn;
     int                 new;
     int                 i;
     
@@ -1051,6 +1059,13 @@ SITEfree(SITE *sp)
 	sp->FNLnames.data = NULL;
 	sp->FNLnames.size = 0;
     }
+    if (sp->HashFeedList) {
+	for (hf = sp->HashFeedList; hf; hf = hn) {
+	    hn = hf->next;
+	    free(hf);
+	}
+	sp->HashFeedList = NULL;
+    }
 
     /* If this site was a master, find a new one. */
     if (sp->IsMaster) {
