@@ -1,4 +1,4 @@
-/*  $Id: nnrpd.c 7269 2005-06-07 03:47:54Z eagle $
+/*  $Id: nnrpd.c 7731 2008-04-06 08:40:29Z iulius $
 **
 **  NNTP server for readers (NNRP) for InterNetNews.
 **
@@ -130,7 +130,7 @@ static CMDENT	CMDtable[] = {
     {	"last",		CMDnextlast,	true,	1,	1,
 	NULL },
     {	"list",		CMDlist,	true,	1,	3,
-	"[active|active.times|extensions|newsgroups|distributions|distrib.pats|overview.fmt|subscriptions|motd]" },
+	"[active|active.times|distrib.pats|distributions|extensions|moderators|motd|newsgroups|overview.fmt|subscriptions]" },
     {	"listgroup",	CMDgroup,	true,	1,	2,
 	"newsgroup" },
     {	"mode",		CMDmode,	false,	2,	2,
@@ -385,6 +385,7 @@ Address2Name6(struct sockaddr *sa, char *hostname, int i)
     int ret;
     bool valid = 0;
     struct addrinfo hints, *res, *res0;
+    char *p;
 
     /* Get the official hostname, store it away. */
     ret = getnameinfo( sa, SA_LEN( sa ), hostname, i, NULL, 0, NI_NAMEREQD );
@@ -423,9 +424,13 @@ Address2Name6(struct sockaddr *sa, char *hostname, int i)
 
     freeaddrinfo( res0 );
 
-    if( valid ) return true;
-    else
-    {
+    if (valid) {
+        /* Make all lowercase for matching. */
+        for (p = hostname; *p != '\0'; p++)
+            if (CTYPE(isupper, *p))
+                *p = tolower(*p);
+        return true;
+    } else {
 	HostErrorStr = mismatch_error;
 	return false;
     }
