@@ -1,4 +1,4 @@
-/*  $Id: python.c 6250 2003-03-03 15:32:13Z alexk $
+/*  $Id: python.c 7893 2008-06-22 10:24:42Z iulius $
 **
 **  python.c: Embed Python in the style of nnrpd's TCL and Perl stuff
 **            (authentication and authorization hooks only at this point).
@@ -8,6 +8,14 @@
 **  This code bases on Python work for innd filtering done by
 **  G.J. Andruk <meowing@banet.net>. Also it borrows some ideas from
 **  TCL/Perl work done by Bob Heiney and Christophe Wolfhugel.
+**
+**  A quick note regarding Python exceptions:  functions like
+**      PyObject_GetAttrString(PyObject *o, const char *attr_name)
+**  raise an exception when they fail, even though they return NULL.
+**  And as exceptions accumulate from caller to caller and so on,
+**  it generates weird issues with Python scripts afterwards.  So such
+**  uses should be checked before.  For instance with:
+**      PyObject_HasAttrString(PyObject *o, const char *attr_name). 
 */
 
 #include "config.h"
@@ -225,7 +233,7 @@ int PY_authenticate(char* file, char *Username, char *Password, char *errorstrin
 */
 void PY_access(char* file, struct vector *access_vec, char *Username) {
     PyObject	*result, *key, *value, *proc;
-    char	*skey, *svalue, *temp;
+    char	*buffer;
     int		authnum;
     int		i;
 
@@ -281,7 +289,7 @@ void PY_access(char* file, struct vector *access_vec, char *Username) {
 
     /* Check the response */
     if (result == NULL || result == Py_None || !PyDict_Check(result)) {
-        syslog(L_ERROR, "python access method returned wrong result - expected a dictionary");
+        syslog(L_ERROR, "python access method returned wrong result -- expected a dictionary");
 	Reply("%d Internal Error (7).  Goodbye\r\n", NNTP_ACCESS_VAL);
 	ExitWithStats(1, true);
      }
@@ -291,6 +299,8 @@ void PY_access(char* file, struct vector *access_vec, char *Username) {
 
     /* store dict values in proper format in access vector */
     i = 0;
+    buffer = xmalloc(BIG_BUFFER);
+
     while(PyDict_Next(result, &i, &key, &value)) {
         if (!PyString_Check(key)) {
             syslog(L_ERROR, "python access method return dictionary key %i not a string", i);
@@ -302,22 +312,17 @@ void PY_access(char* file, struct vector *access_vec, char *Username) {
             Reply("%d Internal Error (7).  Goodbye\r\n", NNTP_ACCESS_VAL);
             ExitWithStats(1, false);
         }
-        
-        temp = PyString_AsString(key);
-        skey = xstrdup(temp);
-        
-        temp = PyString_AsString(value);
-        svalue = xstrdup(temp);
-        
-        skey = strcat(skey, ": \"");
-        skey = strcat(skey, svalue);
-        skey = strcat(skey, "\"\n");
-        vector_add(access_vec, skey);
-        
-        free(skey);
-        free(svalue);
+
+        strlcpy(buffer, PyString_AsString(key), BIG_BUFFER);
+        strlcat(buffer, ": \"", BIG_BUFFER);
+        strlcat(buffer, PyString_AsString(value), BIG_BUFFER);
+        strlcat(buffer, "\"\n", BIG_BUFFER);
+
+        vector_add(access_vec, xstrdup(buffer));
     }
- 
+
+    free(buffer);
+
     /* Clean up the dictionary object */
     PyDict_Clear(PYauthinfo);
     /* Clean up dictionary items */
@@ -413,7 +418,7 @@ int PY_dynamic(char *Username, char *NewsGroup, int PostFlag, char **reply_messa
     /* Check the response */
     if (result == NULL || (result != Py_None && !PyString_Check(result)))
     {
-        syslog(L_ERROR, "python dyanmic method (%s access) returned wrong result: %s", PostFlag ? "post" : "read", result);
+        syslog(L_ERROR, "python dynamic method (%s access) returned wrong result: %s", PostFlag ? "post" : "read", result);
 	Reply("%d Internal Error (7).  Goodbye\r\n", NNTP_ACCESS_VAL);
 	ExitWithStats(1, false);
     }
@@ -448,7 +453,9 @@ int PY_dynamic(char *Username, char *NewsGroup, int PostFlag, char **reply_messa
 
 
 /*
-**  This runs when nnrpd shuts down.
+**  This runs when nnrpd shuts down.  If Python is closed and reopened
+**  in the same process, files and dynamic_file are reused so they
+**  must point to NULL.
 */
 void
 PY_close_python(void)
@@ -456,9 +463,12 @@ PY_close_python(void)
     if (files != NULL) {
 	hash_traverse(files, file_trav, NULL);
 	hash_free(files);
+        files = NULL;
     }
-    if (dynamic_file != NULL)
+    if (dynamic_file != NULL) {
 	free(dynamic_file);
+        dynamic_file = NULL;
+    }
 }
 
 /*
@@ -565,7 +575,7 @@ void PY_load_python() {
         Py_Initialize();
     
         /* It makes Python sad when its stdout and stderr are closed. */
-        if (feof(stdout) || feof(stderr))
+        if ((fileno(stdout) == -1) || (fileno(stderr) == -1))
             PyRun_SimpleString("import sys; sys.stdout=sys.stderr=open('/dev/null', 'a')");
    
         /* See if Python initialized OK */
@@ -601,24 +611,37 @@ void PY_load_python() {
 **  the corresponding PyObject, or NULL if not found.
 */
 void
-PYdefonemethod(PyFile *fp, int type, int method, char *methname) {
+PYdefonemethod(PyFile *fp, int type, int method, char *methname, int realtype) {
     PyObject **methptr;
 
     methptr = &fp->procs[type][method];
+    /* There is no need to check the existence of methods useless for our realtype. */
+    if (type == realtype) {
+        /*
+        ** We check with HasAttrString() the existence of the method because
+        ** otherwise, in case it does not exist, an exception is raised by Python,
+        ** although the result of the function is NULL.
+        */
+        if (PyObject_HasAttrString(PYAuthObject, (char *) methname) == 1) {
+            /* Get a pointer to given method. */
+            *methptr = PyObject_GetAttrString(PYAuthObject, (char *) methname);
+        } else {
+            *methptr = NULL;
+        }
 
-    /* Get a pointer to given method */
-    *methptr = PyObject_GetAttrString(PYAuthObject, methname);
-
-    /* See if such method is defined */
-    if (*methptr == NULL)
-        syslog(L_NOTICE, "python method %s not found", methname);
-    else {
-        /* See if it is callable */
-        if (PyCallable_Check(*methptr) == 0) {
-	    syslog(L_ERROR, "python object %s found but not a function", methname);
-	    Py_DECREF(*methptr);
-	    *methptr = NULL;
-	}
+        /* See if such method is defined */
+        if (*methptr == NULL)
+            syslog(L_NOTICE, "python method %s not found", methname);
+        else {
+            /* See if it is callable */
+            if (PyCallable_Check(*methptr) == 0) {
+                syslog(L_ERROR, "python object %s found but not a function", methname);
+                Py_DECREF(*methptr);
+                *methptr = NULL;
+            }
+        }
+    } else {
+        *methptr = NULL;
     }
 }
 
@@ -628,34 +651,34 @@ PYdefonemethod(PyFile *fp, int type, int method, char *methname) {
 **  pointers to them so that we could call them from nnrpd.
 */
 void
-PYdefmethods(PyFile *fp)
+PYdefmethods(PyFile *fp, int realtype)
 {
     /* Get a reference to authenticate() method */
-    PYdefonemethod(fp, PYTHONauthen, PYTHONmain, "authenticate");
+    PYdefonemethod(fp, PYTHONauthen, PYTHONmain, "authenticate", realtype);
 
     /* Get a reference to authen_init() method */
-    PYdefonemethod(fp, PYTHONauthen, PYTHONinit, "authen_init");
+    PYdefonemethod(fp, PYTHONauthen, PYTHONinit, "authen_init", realtype);
     
     /* Get a reference to authen_close() method */
-    PYdefonemethod(fp, PYTHONauthen, PYTHONclose, "authen_close");
+    PYdefonemethod(fp, PYTHONauthen, PYTHONclose, "authen_close", realtype);
 
     /* Get a reference to access() method */
-    PYdefonemethod(fp, PYTHONaccess, PYTHONmain, "access");
+    PYdefonemethod(fp, PYTHONaccess, PYTHONmain, "access", realtype);
     
     /* Get a reference to access_init() method */
-    PYdefonemethod(fp, PYTHONaccess, PYTHONinit, "access_init");
+    PYdefonemethod(fp, PYTHONaccess, PYTHONinit, "access_init", realtype);
     
     /* Get a reference to access_close() method */
-    PYdefonemethod(fp, PYTHONaccess, PYTHONclose, "access_close");
+    PYdefonemethod(fp, PYTHONaccess, PYTHONclose, "access_close", realtype);
     
     /* Get a reference to dynamic() method */
-    PYdefonemethod(fp, PYTHONdynamic, PYTHONmain, "dynamic");
+    PYdefonemethod(fp, PYTHONdynamic, PYTHONmain, "dynamic", realtype);
     
     /* Get a reference to dynamic_init() method */
-    PYdefonemethod(fp, PYTHONdynamic, PYTHONinit, "dynamic_init");
+    PYdefonemethod(fp, PYTHONdynamic, PYTHONinit, "dynamic_init", realtype);
     
     /* Get a reference to dynamic_close() method */
-    PYdefonemethod(fp, PYTHONdynamic, PYTHONclose, "dynamic_close");
+    PYdefonemethod(fp, PYTHONdynamic, PYTHONclose, "dynamic_close", realtype);
 }
 
 
@@ -689,7 +712,7 @@ PY_setup(int type, int method, char *file)
             ExitWithStats(1, false);
         } else {
             /* Set up pointers to known Python methods */
-            PYdefmethods(fp);
+            PYdefmethods(fp, type);
         }
         hash_insert(files, file, fp);
 
